package Qt::Gui::QAccessibleBridgePlugin;
# THE FOLLOWING CODE IS AUTOMATED, ANY MODIFICATION WILL BE LOST!
# classname: QAccessibleBridgePlugin
# file     : QtGui/qaccessiblebridge.h

use strict;
use warnings;
#use Carp;

our $VERSION = '0.01_03';
use base qw/Qt::Gui::QAccessibleBridgeFactoryInterface/;
#our @ISA = qw/Qt::Gui::QAccessibleBridgeFactoryInterface/;


# FIXME: operator overload


1;

=head1 NAME

Qt::Gui::QAccessibleBridgePlugin

=head1 PUBLIC METHODS

=over

=item   QAccessibleBridgePlugin(QObject * parent)

=item   QAccessibleBridgePlugin(QObject * parent = 0)

=item   ~QAccessibleBridgePlugin()

=item  QAccessibleBridge * create(const QString & key)

=item  QStringList keys()


=back

=head1 ENUM VALUES

=over


=back

=head2 EXPORT

None by default.

=head1 AUTHOR

Dongxu Ma E<lt>dongxu@cpan.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright (C) 2011 - 2011 by Dongxu Ma

This library is free software; you can redistribute it and/or modify
it under the same terms as Perl itself.

See L<http://dev.perl.org/licenses/artistic.html>

=cut
